==> haskell-wai-conduit-3.0.0.4-706-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-7kY6D3gHNHvClGAHcF5Bh5
key:                  wai-conduit-3.0.0.4-7kY6D3gHNHvClGAHcF5Bh5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  7a34e40f7b4b671fcf02602479c211e3
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-7kY6D3gHNHvClGAHcF5Bh5
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-IACzArib6WtLejx9Lk1hSM
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0 transformers-0.6.1.0
    wai-3.2.4-9STWQp0whD3L0eUd8mHjKL

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-707-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-FCUcyUmWU3R6skmm2BdnzL
key:                  wai-conduit-3.0.0.4-FCUcyUmWU3R6skmm2BdnzL
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  88a308600aae4be2fc9ef622b4a2d249
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-FCUcyUmWU3R6skmm2BdnzL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-Kqk4qvMFRgW2tkqUOvpcLF
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0 transformers-0.6.1.0
    wai-3.2.4-9STWQp0whD3L0eUd8mHjKL

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
